@@ -22,5 +22,8 @@ func NewHost(schemaDirectoryPath string) plugin.Host {
 		}),
 		deploytest.NewProviderLoader("kubernetes", semver.MustParse("1.0.0"), func() (plugin.Provider, error) {
 			return Kubernetes(schemaDirectoryPath)
+		}),
+		deploytest.NewProviderLoader("aws-native", semver.MustParse("1.0.0"), func() (plugin.Provider, error) {
+			return AwsNative(schemaDirectoryPath)
 		}))
 }
